"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useGraphqlWatchQueryVars = exports.useGraphqlWatchQuery = void 0;
var tslib_1 = require("tslib");
var react_1 = require("react");
var prostore_apollo_1 = require("@proscom/prostore-apollo");
var prostore_react_1 = require("@proscom/prostore-react");
var ApolloClientsContext_1 = require("./ApolloClientsContext");
/**
 * Creates GraphqlWatchQueryStore and subscribes to it using useRequestStore.
 * Effectively this requests data from the apollo based on the provided variables and queryOptions
 *
 * @returns {{load, check, state}} - Current request state
 */
function useGraphqlWatchQuery(_a) {
    var client = _a.client, queryOptions = _a.queryOptions, variables = _a.variables, options = _a.options, hookOptions = _a.hookOptions;
    var actualClient = ApolloClientsContext_1.useContextApolloClient(client);
    var ssrContext = react_1.useContext(prostore_react_1.ProstoreSsrContext);
    var store = react_1.useMemo(function () {
        return new prostore_apollo_1.GraphqlWatchQueryStore(tslib_1.__assign({ ssrContext: ssrContext, client: actualClient }, queryOptions));
    }, [ssrContext, actualClient, queryOptions]);
    return prostore_react_1.useRequestStore(store, variables, options, hookOptions);
}
exports.useGraphqlWatchQuery = useGraphqlWatchQuery;
/**
 * The same as useGraphqlWatchQuery, but it uses variableCreator which is supplied to useMemo and
 * can be used to memoize query variables. This may be used when the default behavior of deeply
 * comparing variables is not preferable (i.e., it is not fast enough, or variables are not simple objects)
 *
 * @returns {{load, check, state}} - Current request state
 */
function useGraphqlWatchQueryVars(_a) {
    var variableCreator = _a.variableCreator, queryProps = tslib_1.__rest(_a, ["variableCreator"]);
    var variables = react_1.useMemo.apply(void 0, variableCreator);
    return useGraphqlWatchQuery(tslib_1.__assign(tslib_1.__assign({}, queryProps), { variables: variables }));
}
exports.useGraphqlWatchQueryVars = useGraphqlWatchQueryVars;
//# sourceMappingURL=useGraphqlWatchQuery.js.map